/*========================================================================
 * Copyright (c) 2009 Tampere University of Technology, Finland
 * 
 * Permission is hereby granted, free of charge, to any person 
 * obtaining a copy of this software and associated documentation 
 * files (the "Software"), to deal in the Software without restriction, 
 * including without limitation the rights to use, copy, modify, merge, 
 * publish, distribute, sublicense, and/or sell copies of the Software, 
 * and to permit persons to whom the Software is furnished to do so, 
 * subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.  
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *======================================================================*/

// Code to find the distance in metres between a lat/lng point and a polyline of lat/lng points
// All in WGS84. Free for any use.
//
// Bill Chadwick 2007

		// Construct a bdccGeo from its latitude and longitude in degrees
		function bdccGeo(lat, lon)
		{
			var theta = (lon * Math.PI / 180.0);
			var rlat = bdccGeoGeocentricLatitude(lat * Math.PI / 180.0);
			var c = Math.cos(rlat);
			this.x = c * Math.cos(theta);
			this.y = c * Math.sin(theta);
			this.z = Math.sin(rlat);
		}
		bdccGeo.prototype = new bdccGeo();

		// internal helper functions =========================================

	    // Convert from geographic to geocentric latitude (radians).
		function bdccGeoGeocentricLatitude(geographicLatitude)
		{
			var flattening = 1.0 / 298.257223563;//WGS84
		    var f = (1.0 - flattening) * (1.0 - flattening);
			return Math.atan((Math.tan(geographicLatitude) * f));
		}

		// Convert from geocentric to geographic latitude (radians)
		function bdccGeoGeographicLatitude (geocentricLatitude)
		{
			var flattening = 1.0 / 298.257223563;//WGS84
		    var f = (1.0 - flattening) * (1.0 - flattening);
			return Math.atan(Math.tan(geocentricLatitude) / f);
		}

		 // Returns the two antipodal points of intersection of two great
		 // circles defined by the arcs geo1 to geo2 and
		 // geo3 to geo4. Returns a point as a Geo, use .antipode to get the other point
		function bdccGeoGetIntersection( geo1,  geo2,  geo3,  geo4)
		{
			var geoCross1 = geo1.crossNormalize(geo2);
			var geoCross2 = geo3.crossNormalize(geo4);
			return geoCross1.crossNormalize(geoCross2);
		}

		//from Radians to Meters
		function bdccGeoRadiansToMeters(rad)
		{
			return rad * 6378137.0; // WGS84 Equatorial Radius in Meters
		}

		//from Meters to Radians
		function bdccGeoMetersToRadians(m)
		{
			return m / 6378137.0; // WGS84 Equatorial Radius in Meters
		}

		// properties =================================================


		bdccGeo.prototype.getLatitudeRadians = function()
		{
			return (bdccGeoGeographicLatitude(Math.atan2(this.z,
				Math.sqrt((this.x * this.x) + (this.y * this.y)))));
		}

		bdccGeo.prototype.getLongitudeRadians = function()
		{
			return (Math.atan2(this.y, this.x));
		}

		bdccGeo.prototype.getLatitude = function()
		{
			return this.getLatitudeRadians()  * 180.0 / Math.PI;
		}

		bdccGeo.prototype.getLongitude = function()
		{
			return this.getLongitudeRadians()  * 180.0 / Math.PI ;
		}

		// Methods =================================================

        //Maths
		bdccGeo.prototype.dot = function( b)
		{
			return ((this.x * b.x) + (this.y * b.y) + (this.z * b.z));
		}

        //More Maths
		bdccGeo.prototype.crossLength = function( b)
		{
			var x = (this.y * b.z) - (this.z * b.y);
			var y = (this.z * b.x) - (this.x * b.z);
			var z = (this.x * b.y) - (this.y * b.x);
			return Math.sqrt((x * x) + (y * y) + (z * z));
		}

	  //More Maths
		bdccGeo.prototype.scale = function( s)
		{
		    var r = new bdccGeo(0,0);
		    r.x = this.x * s;
		    r.y = this.y * s;
		    r.z = this.z * s;
			return r;
		}

        // More Maths
		bdccGeo.prototype.crossNormalize = function( b)
		{
			var x = (this.y * b.z) - (this.z * b.y);
			var y = (this.z * b.x) - (this.x * b.z);
			var z = (this.x * b.y) - (this.y * b.x);
			var L = Math.sqrt((x * x) + (y * y) + (z * z));
			var r = new bdccGeo(0,0);
			r.x = x / L;
			r.y = y / L;
			r.z = z / L;
			return r;
		}

	  // point on opposite side of the world to this point
		bdccGeo.prototype.antipode = function()
		{
			return this.scale(-1.0);
		}






        //distance in radians from this point to point v2
		bdccGeo.prototype.distance = function( v2)
		{
			return Math.atan2(v2.crossLength(this), v2.dot(this));
		}

	  //returns in meters the minimum of the perpendicular distance of this point from the line segment geo1-geo2
	  //and the distance from this point to the line segment ends in geo1 and geo2
		bdccGeo.prototype.distanceToLineSegMtrs = function(geo1, geo2)
		{

			//point on unit sphere above origin and normal to plane of geo1,geo2
			//could be either side of the plane
			var p2 = geo1.crossNormalize(geo2);

			// intersection of GC normal to geo1/geo2 passing through p with GC geo1/geo2
			var ip = bdccGeoGetIntersection(geo1,geo2,this,p2);

			//need to check that ip or its antipode is between p1 and p2
			var d = geo1.distance(geo2);
			var d1p = geo1.distance(ip);
			var d2p = geo2.distance(ip);
			//window.status = d + ", " + d1p + ", " + d2p;
			if ((d >= d1p) && (d >= d2p))
				return bdccGeoRadiansToMeters(this.distance(ip));
			else
			{
				ip = ip.antipode();
				d1p = geo1.distance(ip);
				d2p = geo2.distance(ip);
			}
			if ((d >= d1p) && (d >= d2p))
				return bdccGeoRadiansToMeters(this.distance(ip));
			else
				return bdccGeoRadiansToMeters(Math.min(geo1.distance(this),geo2.distance(this)));
		}

        // distance in meters from GLatLng point to GPolyline or GPolygon poly
        function bdccGeoDistanceToPolyMtrs(poly, point)
        {
            var d = 999999999;
            var i;
            var p = new bdccGeo(point.lat(),point.lng());
            for(i=0; i<(poly.getVertexCount()-1); i++)
                 {
                    var p1 = poly.getVertex(i);
                    var l1 = new bdccGeo(p1.lat(),p1.lng());
                    var p2 = poly.getVertex(i+1);
                    var l2 = new bdccGeo(p2.lat(),p2.lng());
                    var dp = p.distanceToLineSegMtrs(l1,l2);
                    if(dp < d)
                        d = dp;
                 }
             return d;
        }

        // get a new GLatLng distanceMeters away on the compass bearing azimuthDegrees
        // from the GLatLng point - accurate to better than 200m in 140km (20m in 14km) in the UK

        function bdccGeoPointAtRangeAndBearing (point, distanceMeters, azimuthDegrees)
        {
             var latr = point.lat() * Math.PI / 180.0;
             var lonr = point.lng() * Math.PI / 180.0;

             var coslat = Math.cos(latr);
             var sinlat = Math.sin(latr);
             var az = azimuthDegrees* Math.PI / 180.0;
             var cosaz = Math.cos(az);
             var sinaz = Math.sin(az);
             var dr = distanceMeters / 6378137.0; // distance in radians using WGS84 Equatorial Radius
             var sind = Math.sin(dr);
             var cosd = Math.cos(dr);

            return new GLatLng(Math.asin((sinlat * cosd) + (coslat * sind * cosaz)) * 180.0 / Math.PI,
            (Math.atan2((sind * sinaz), (coslat * cosd) - (sinlat * sind * cosaz)) + lonr) * 180.0 / Math.PI);
        }

/* Weather Cameras Widget spesific code starts here */
var userClickedPoint = undefined;
var useVirtualCenter = undefined;
var userClickedMarker = undefined;
var fromMarker = undefined;
var toMarker = undefined;
var myPolyline = undefined;

// Add small zoom controls over the map
map.addControl(new GSmallMapControl(),new GControlPosition(G_ANCHOR_TOP_RIGHT, new GSize(10,10)));

var markers = new Array();

// take double click zoom off
map.disableDoubleClickZoom();

/*
 * Calculating zoom focus point with static size sidebar
 * http://mapsapi.googlepages.com/collapsible.htm
 */
function virtualCenter(point, xOffs){
	var pixCenter = map.fromLatLngToDivPixel(point);
 	var virtualPxCenter = new GPoint(pixCenter.x + xOffs/2, pixCenter.y);
	return map.fromDivPixelToLatLng(virtualPxCenter);
}

function refocus(){
	if(useVirtualCenter)
  	{
    	var pnt = virtualCenter(map.getCenter(),283);//sideBlock width
    	map.setFocus(pnt);
  	}else{
    	map.setFocus(); //reset
  	}
}
GEvent.addListener(map,"moveend",function(){
  	refocus();
});


var directions = undefined;

/* When user clicks the map add a marker. When user clicks second point
 * on the map add another marker and use these two markers to get
 * directions from point A to B. */
myClickListener = GEvent.addListener(map, "click", function(marker, point) {
    userClickedPoint = point;
    userClickedMarker = marker;
    // If user clicked marker, center map over it
    if(marker != undefined && marker.cameraUrl != undefined) {
    	map.setCenter(virtualCenter(marker.getPoint(),-283));
	}
	// First marker
    if(fromMarker == undefined && toMarker == undefined) {
    	fromMarker = new GMarker(point);
		map.addOverlay(fromMarker);
	}
	// second marker
	else if (toMarker == undefined){
		toMarker = new GMarker(point);

		// Add markers to an array
		var myWaypoints = new Array();
		myWaypoints.push(fromMarker.getPoint().lat() + ", " + fromMarker.getPoint().lng());
		myWaypoints.push(toMarker.getPoint().lat() + ", " + toMarker.getPoint().lng());

		// only map is defined, no textual directions is used
		directions = new GDirections(map);

		// Add event listener to do some stuff after directions is ready
		GEvent.addListener(directions, "load", onGDirectionsLoad);
		GEvent.addListener(directions, "error", onGDirectionsError);

		// Load directions based on two markers in an array
		directions.loadFromWaypoints(myWaypoints, {'getPolyline':true});
		
   		// set mouse cursor to wait
   		map.getDragObject().setDraggableCursor("wait");

   		// remove first marker
		map.removeOverlay(fromMarker);
	}
	else {
		fromMarker = undefined;
		toMarker = undefined;
		map.getDragObject().setDraggableCursor("auto");
	}
});

function onGDirectionsError(){
	var status = "GDirections error" + "<br>Status code: " + directions.getStatus().code;
	map.openInfoWindow(fromMarker.getPoint(), status);
	fromMarker = undefined;
	toMarker = undefined;
	myPolyline = undefined;
	directions = undefined;
	map.getDragObject().setDraggableCursor("auto");
}

/* After directions are ready to be shown on the map we want to do some
 * heavy calculation and show markers with links to weather cameras near
 * the polyline representing the directions */
function onGDirectionsLoad(){
	/* At first we do rough estimation of the area containing interesting
	 * weather cameras. There is about 300 weather camera markers and we
	 * will not want to calculate distance from the polyline to all of
	 * them. Only markers inside rectancle are included in calculation */
	var top = 70;
	var down = 59;
	var right = 32;
	var left = 21;

	var ytolerance = 0.3;
	var xtolerance = 0.4;

	// Only the last infoWindow stays visible
	// If there is no error, this infoWindow will be replaced with one with 
	// route length and duration
	var debug1 = "Optimization error onGDirectionsLoad function";
	map.openInfoWindow(fromMarker.getPoint(), debug1);

	if(fromMarker.getLatLng().lat() > toMarker.getLatLng().lat()) {
		top = fromMarker.getLatLng().lat() + ytolerance;
		down = toMarker.getLatLng().lat() - ytolerance;
	}
	else {
		top = toMarker.getLatLng().lat() + ytolerance;
		down = fromMarker.getLatLng().lat() - ytolerance;
	}
	if(fromMarker.getLatLng().lng() > toMarker.getLatLng().lng()) {
		right = fromMarker.getLatLng().lng() + xtolerance;
		left = toMarker.getLatLng().lng() - xtolerance;
	}
	else {
		left = fromMarker.getLatLng().lng() - xtolerance;
		right = toMarker.getLatLng().lng() + xtolerance;
	}

	/*
		var polygon = new GPolygon([
    		new GLatLng(top, right),
    		new GLatLng(down, right),
    		new GLatLng(down, left),
    		new GLatLng(top, left),
    		new GLatLng(top, right)
  			], "#f33f00", 1, 1, "#0000ff", 0.2);
		map.addOverlay(polygon);
	*/

	// Get polyline from directions
	myPolyline = directions.getPolyline();

	// Delete quite many vertexes from the polyline
	var myVertexArray = new Array();
	myVertexArray.push(myPolyline.getVertex(0));
	myVertexArray.push(myPolyline.getVertex(myPolyline.getVertexCount()-1));
	for(i=1; i < myPolyline.getVertexCount()-1; i=i+1) {
		if(i%50) {
			continue;
		}
		myVertexArray.push(myPolyline.getVertex(i));
	}
	myPolyline = new GPolygon(myVertexArray);

	// Get directions length and duration
	var meters = directions.getDistance().meters / 1000;
	var duration = directions.getDuration().html;
	var myHtml = meters + " km<br/> (Driving time " + duration + ")";

	// For all the markers inside our rough estimate rectancle
	// Calculate distance to the polyline
	// This takes a looong time...
	for(i=0; i<=markers.length-1; i=i+1) {
		// Reset toPolyline property of the marker
		markers[i].toPolyline = 5001;
		if(markers[i].getLatLng().lat() <  top &&
			markers[i].getLatLng().lat() > down &&
			markers[i].getLatLng().lng() < right &&
			markers[i].getLatLng().lng() > left) {
			// Calculate distance to the polyline and save it to marker property
			markers[i].toPolyline = Math.round(bdccGeoDistanceToPolyMtrs(myPolyline,markers[i].getPoint()));
		}
		// If a marker is closer than 5000 meters to the polyline
		// show it on the map
		if(markers[i].toPolyline < 5000) {
			map.addOverlay(markers[i]);
		}
	}

	// Set cursor back to normal
	map.getDragObject().setDraggableCursor("auto");

	// Open info window with directions distance and duration
	map.openInfoWindow(toMarker.getPoint(), myHtml /*+ "<br>Polyline vertex count: " + myPolyline.getVertexCount()*/ );
	myPolyline = undefined;
	directions = undefined;

	// Markers are not needed anymore
	fromMarker = undefined;
	toMarker = undefined;
}

/* Create customized markers */
function createMarker(point, urli, paikka) {
	GMarker.prototype.toPolyline;
	var marker = new GMarker(point);
	marker.toPolyline = 5001;
	marker.cameraUrl = urli;
	marker.cameraLoc = paikka;
  		/*GEvent.addListener(marker, "click", function() {
			var osoite = "http://koti.mbnet.fi/fixxxeri/test.php?urli=" + urli + "?code=" + 666 * Math.random();
			marker.openInfoWindowHtml("<p>Location: " + paikka + "</p><p><img src=\""+osoite+"\" width=\"244\" height=\"200\"</p>" + marker.toPolyline + " meters from the route.");
  		});*/
	markers.push(marker);
	return markers[markers.length-1];
}

/* Adding weather camera information */
var point = new GLatLng(61.747131193562794,26.109008789062500);
(createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950901.html','Vt 4 Joutsa'));
var point = new GLatLng(62.075598395855216,26.034851074218754);
(createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950702.html','Vt 4 Vesto'));
var point = new GLatLng(61.803635035287961,27.600059509277344);
(createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350901.html','Vt 5 Kielkallio'));
var point = new GLatLng(61.443527243064707,26.682357788085941);
(createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352301.html','Vt 5 Mäntyharju, Vihantasalmi'));
var point = new GLatLng(61.420706666989069,26.395339965820309);
(createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353201.html','Vt 5 Pertunmaa, Kuortti'));
var point = new GLatLng(62.900222699857267,27.674560546875000);
(createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0850101.html','Vt 5 Kuopio'));
var point = new GLatLng(62.585122004378015,27.604522705078125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0850602.html','Vt 5 Oravikoski'));
var point = new GLatLng(63.033949548010355,27.656536102294918);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853302.html','Vt 5 Räimä'));
var point = new GLatLng(62.884578753560049,27.636280059814453);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853801.html','Vt 5 Kuopio, Siikalahti'));
var point = new GLatLng(63.539986896664608,27.248840332031246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853601.html','Vt 5 Iisalmi'));
var point = new GLatLng(63.358287917961718,27.416381835937500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853702.html','Vt 5 Lapinlahti, Alapitkä'));
var point = new GLatLng(62.942107345625089,27.668380737304691);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851400.html','Vt 5 Kallansilta 3'));
var point = new GLatLng(62.952413033050085,27.675933837890625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851500.html','Vt 5 Kallansilta 4'));
var point = new GLatLng(62.312941554000922,27.859268188476562);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852101.html','Vt 5 Varkaus'));
var point = new GLatLng(63.307131278070301,27.447967529296875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852201.html','Vt 5 Lapinlahti'));
var point = new GLatLng(62.736802722811909,27.588043212890629);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851002.html','Vt 5 Vehmasmäki'));
var point = new GLatLng(62.934297589896659,27.667694091796879);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852401.html','Vt 5 Kuopio, Päiväranta'));
var point = new GLatLng(63.868807383116881,27.433547973632812);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0850802.html','Vt 5 Sukeva'));
var point = new GLatLng(61.607702415026260,29.491424560546875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352202.html','Vt 6 Särkisalmi'));
var point = new GLatLng(61.186617500645127,28.750534057617191);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352502.html','Vt 6 Imatra'));
var point = new GLatLng(62.761640744490101,29.854660034179688);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0850201.html','Vt 6 Kontiolahti'));
var point = new GLatLng(61.903399056121820,29.812774658203125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0854101.html','Vt 6 Kesälahti'));
var point = new GLatLng(63.095379892156579,29.609527587890625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852501.html','Vt 6 Ahmovaara'));
var point = new GLatLng(62.477752910927954,29.955596923828125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851601.html','Vt 6 Pyhäselkä, Haavanpää'));
var point = new GLatLng(62.079939149898195,29.943237304687500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851801.html','Vt 6 Puhos'));
var point = new GLatLng(63.622474049014734,28.919448852539059);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851100.html','Vt 6 Nurmes'));
var point = new GLatLng(63.871982591810948,28.459739685058594);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253501.html','Vt 6 Sotkamo, Maanselkä'));
var point = new GLatLng(62.252621628098062,26.105661392211911);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950402.html','Vt 9 Metsolahti'));
var point = new GLatLng(62.314536733553766,26.492843627929691);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950501.html','Vt 9 Nälkämäki'));
var point = new GLatLng(62.632507041957830,27.110137939453125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0850901.html','Vt 9 Suonenjoki'));
var point = new GLatLng(62.002194090264076,26.659355163574219);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352602.html','Vt 13 Kangasniemi'));
var point = new GLatLng(61.869101324915235,28.899536132812496);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0351600.html','Vt 14 Savonlinna 3'));
var point = new GLatLng(61.876222882421224,28.843231201171879);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0351700.html','Vt 14 Savonlinna 2'));
var point = new GLatLng(61.869101324915235,28.862457275390625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0351800.html','Vt 14 Savonlinna 4'));
var point = new GLatLng(61.296626186717411,27.179489135742184);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350502.html','Vt 15 Ostolahti'));
var point = new GLatLng(62.629666072131442,29.698791503906243);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853101.html','Vt 17 Noljakka'));
var point = new GLatLng(62.931016871102251,28.066291809082031);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852802.html','Vt 17 Vartiala'));
var point = new GLatLng(62.787085877561310,28.660240173339844);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851901.html','Vt 17 Tuusniemi, Paakkila'));
var point = new GLatLng(62.700608727922628,28.959960937500000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853001.html','Vt 17 Ulla'));
var point = new GLatLng(62.535127926341225,28.910007476806641);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350701.html','Vt 23 Karvio'));
var point = new GLatLng(62.497735746723464,28.380432128906243);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853202.html','Vt 23 Soisalo'));
var point = new GLatLng(62.561480214011205,29.142093658447266);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852902.html','Vt 23 Liperi, Kaatamo'));
var point = new GLatLng(63.604622113085760,27.107391357421875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852002.html','Vt 27 Iisalmi, Runni'));
var point = new GLatLng(61.160131616275741,26.305732727050781);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353301.html','Kt 46 Uimila'));
var point = new GLatLng(61.190257570225242,28.753967285156246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350802.html','Kt 62 Imatra'));
var point = new GLatLng(61.579610336764489,27.649497985839844);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353402.html','Kt 62 Anttola'));
var point = new GLatLng(62.699978874867774,26.446838378906243);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0952102.html','Kt 69 Konnevesi, Istunmäki'));
var point = new GLatLng(62.171272298507134,30.629196166992188);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0850302.html','Kt 70 Niirala'));
var point = new GLatLng(62.228915711675072,30.329818725585938);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852301.html','Kt 70 Tohmajärvi'));
var point = new GLatLng(62.024427247391849,27.205581665039066);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352701.html','Kt 72 Haukivuori'));
var point = new GLatLng(63.479650862924238,29.622573852539066);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0850501.html','Kt 73 Vieki'));
var point = new GLatLng(62.913982471432313,30.252914428710941);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0851701.html','Kt 73 Eno, Uimaharju'));
var point = new GLatLng(62.559819047233781,30.173950195312500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0854002.html','Kt 74 Joensuu, Heinävaara'));
var point = new GLatLng(63.341502542055750,28.459739685058594);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852701.html','Kt 75 Hankamäki'));
var point = new GLatLng(63.193708779411047,28.180961608886719);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853902.html','Kt 75 Nilsiä, Pajulahti'));
var point = new GLatLng(63.908924700861569,29.536056518554691);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254001.html','Kt 75 Kuhmo, Lauvuskylä'));
var point = new GLatLng(63.186740583460967,26.334571838378906);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852601.html','Kt 77 Keitele'));
var point = new GLatLng(62.779862949072694,28.013076782226562);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853501.html','St 536 Kuopio, Vehmersalmi'));
var point = new GLatLng(62.984555931777628,28.449096679687500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0853402.html','St 569 Kaavi'));
var point = new GLatLng(62.844492212406635,27.344970703125000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0854402.html','Tie 551 Karttula, Pihkainmäki'));
var point = new GLatLng(66.449691825494227,25.559692382812500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450201.html','Vt 4 Rovaniemi'));
var point = new GLatLng(66.148851805497799,24.967803955078125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451001.html','Vt 4 Loue'));
var point = new GLatLng(65.035350243085176,25.490341186523438);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251300.html','Vt 4 Oulu, Intiö'));
var point = new GLatLng(65.059682751012247,25.447082519531246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250400.html','Vt 4 Oulu, Laanila'));
var point = new GLatLng(63.495283083347445,25.668182373046875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250501.html','Vt 4 Elämäjärvi'));
var point = new GLatLng(65.077483544868301,25.441246032714844);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252300.html','Vt 4 Oulu, Linnanmaa'));
var point = new GLatLng(65.601608647707181,25.192337036132816);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251401.html','Vt 4 Kuivaniemi'));
var point = new GLatLng(64.775881095727456,25.548706054687504);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251502.html','Vt 4 Alatemmes'));
var point = new GLatLng(64.973840801779460,25.513000488281246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251200.html','Vt 4 Oulu, Kiviniemi'));
var point = new GLatLng(64.905492485410548,25.534629821777344);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252500.html','Vt 4 Kempele'));
var point = new GLatLng(65.317421216234223,25.373268127441403);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253201.html','Vt 4 Ii'));
var point = new GLatLng(64.815721264517080,25.485877990722660);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253702.html','Vt 4 Liminka, Haaransilta'));
var point = new GLatLng(64.863524740573254,25.502700805664062);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254400.html','Vt 4 Liminka, Tupos'));
var point = new GLatLng(66.368901947853658,28.729248046875000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453902.html','Vt 5 Posio, Maaninkavaara'));
var point = new GLatLng(66.177156615502099,29.124755859375000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250900.html','Vt 5 Ruka'));
var point = new GLatLng(64.344962157024639,28.089294433593754);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252002.html','Vt 5 Kontiomäki'));
var point = new GLatLng(65.206076002856278,29.002532958984375);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251709.html','Vt 5 Suomussalmi, Palovaara'));
var point = new GLatLng(65.508977766687892,28.905029296875000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253809.html','Vt 5 Taivalkoski, Tyrävaara'));
var point = new GLatLng(64.675325312457801,28.507461547851562);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253901.html','Vt 5 Hyrynsalmi'));
var point = new GLatLng(64.147305150579328,27.966041564941406);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251601.html','Vt 6 Korholanmäki'));
var point = new GLatLng(64.223701100290882,27.728118896484375);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254702.html','Vt 6 Kajaani'));
var point = new GLatLng(63.734820446483475,23.016014099121097);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1050201.html','Vt 8 Kruunupyy'));
var point = new GLatLng(64.005469253531245,23.535461425781246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051200.html','Vt 8 Lohtaja'));
var point = new GLatLng(64.195619049814894,23.749694824218754);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250201.html','Vt 8 Rahja'));
var point = new GLatLng(64.718613040957592,24.965744018554688);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252101.html','Vt 8 Revonlahti'));
var point = new GLatLng(64.491281493732600,24.314975738525387);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252401.html','Vt 8 Parhalahti'));
var point = new GLatLng(65.184759213435754,26.140937805175778);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250101.html','Vt 20 Yli-Kiiminki, Arkala'));
var point = new GLatLng(65.574932925543578,28.240356445312500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251901.html','Vt 20 Taivalkoski, Jurmu'));
var point = new GLatLng(65.362829805619100,26.982421875000000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253301.html','Vt 20 Pudasjärvi'));
var point = new GLatLng(65.834137998426371,28.834648132324215);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252201.html','Vt 20 Kuusamo, Kuolio'));
var point = new GLatLng(65.038248134887439,25.550079345703125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254600.html','Vt 20 Oulu, Rusko'));
var point = new GLatLng(65.964097496662120,24.044952392578125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451401.html','Vt 21 Ylitornio'));
var point = new GLatLng(64.534493839582780,27.230987548828129);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251101.html','Vt 22 Paltamo, Kivesvaara'));
var point = new GLatLng(64.790654408952264,26.128921508789059);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252801.html','Vt 22 Muhos, Hyrkäs'));
var point = new GLatLng(64.570562498253139,26.865005493164059);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254301.html','Vt 22 Vaala'));
var point = new GLatLng(63.999148658695930,24.762496948242188);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251802.html','Vt 27 Ylivieska'));
var point = new GLatLng(63.904168015028411,23.913116455078121);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051901.html','Vt 28 Eskola'));
var point = new GLatLng(64.114199751019584,27.090911865234375);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252601.html','Vt 28 Otanmäki'));
var point = new GLatLng(63.957728469233082,25.372066497802734);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253002.html','Vt 28 Karsikas'));
var point = new GLatLng(65.829218302346817,24.379005432128903);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451909.html','Vt 29 Luukkaankangas'));
var point = new GLatLng(65.838635182562030,24.282875061035156);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451701.html','Vt 29 Tornio'));
var point = new GLatLng(65.807419758729722,24.511528015136719);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452009.html','Vt 29 Kemi'));
var point = new GLatLng(63.360751001709147,23.464050292968750);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051802.html','Kt 68 Evijärvi'));
var point = new GLatLng(64.082705564764439,29.119091033935547);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251001.html','Kt 76 Kuhmo, Tervasalmi'));
var point = new GLatLng(65.029988313183651,27.703056335449219);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253401.html','Kt 78 Puolanka'));
var point = new GLatLng(65.699915749665749,26.672229766845703);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253601.html','Kt 78 Pudasjärvi, Kokkokylä'));
var point = new GLatLng(64.445261021388546,27.812232971191406);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254101.html','Kt 78 Puolanka, Törmänmäki'));
var point = new GLatLng(66.187762762102849,27.593193054199219);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451102.html','Kt 81 Pernu'));
var point = new GLatLng(64.488620038876064,24.987030029296875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252902.html','Kt 86 Vihanti'));
var point = new GLatLng(64.098007193509162,26.338005065917972);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250801.html','Kt 88 Pyhäntä'));
var point = new GLatLng(64.461732219147251,28.898591995239258);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250609.html','Kt 89 Kuhmo, Raiskio'));
var point = new GLatLng(64.545194022210381,29.989242553710941);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1252702.html','Kt 89 Kuhmo, Vartius'));
var point = new GLatLng(64.935689038388716,25.412921905517575);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253101.html','St 816 Oulunsalo'));
var point = new GLatLng(65.371987962908605,25.834350585937504);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254502.html','St 849 Yli-ii, Tannila'));
var point = new GLatLng(65.647659090911972,27.707004547119141);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254201.html','St 862 Pudasjärvi, Iso-Syöte'));
var point = new GLatLng(65.833716347075338,25.320053100585938);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453001.html','St 924 Alaniemi'));
var point = new GLatLng(65.799117394440231,30.102539062500000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254802.html','Tie 866 Kuusamo'));
var point = new GLatLng(63.700159330167175,23.328437805175778);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1052400.html','Tie 13 Nedervetil/Alaveteli'));
var point = new GLatLng(63.396903235178982,22.628746032714844);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1052502.html','Tie 19 Jeppo/Jepua'));
var point = new GLatLng(68.417751782341114,27.406768798828125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450400.html','Vt 4 Saariselkä'));
var point = new GLatLng(67.719861058117559,26.751708984375000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450702.html','Vt 4 Postojoki'));
var point = new GLatLng(66.906371038380271,26.205139160156246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450901.html','Vt 4 Tiainen'));
var point = new GLatLng(69.437304715529976,27.243347167968750);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452301.html','Vt 4 Utsjoki, Petsikko'));
var point = new GLatLng(66.505049484051767,25.729293823242188);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452601.html','Vt 4 Napapiiri'));
var point = new GLatLng(67.189928026311705,27.450714111328125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452701.html','Vt 5 Kairala'));
var point = new GLatLng(66.394623620538937,28.631229400634769);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453902.html','Vt 5 Posio, Maaninkavaara'));
var point = new GLatLng(67.719861058117559,26.751708984375000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1454001.html','Vt 4 Sodankylä, Porttipahta'));
var point = new GLatLng(68.907051417679554,27.014694213867188);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1454101.html','Vt 4 Inari'));
var point = new GLatLng(66.163320349986890,29.118318557739254);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250900.html','Vt 5 Ruka'));
var point = new GLatLng(68.591233423388417,21.794128417968754);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451201.html','Vt 21 Ropinsalmi'));
var point = new GLatLng(67.333246414056973,23.786773681640629);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451309.html','Vt 21 Kolari'));
var point = new GLatLng(68.284254171338617,23.080730438232425);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453102.html','Vt 21 Palojoensuu'));
var point = new GLatLng(66.797320628539055,23.987274169921875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1454201.html','Vt 21 Pello'));
var point = new GLatLng(67.767778186297804,24.843864440917972);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452100.html','Kt 79 Levi'));
var point = new GLatLng(67.860957968661765,24.106492996215817);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451501.html','Kt 79 Äkäsjärvi'));
var point = new GLatLng(67.165158974917119,24.962310791015625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452801.html','Kt 79 Lohiniva'));
var point = new GLatLng(67.560913780047898,25.685005187988285);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450501.html','Kt 80 Tepsa'));
var point = new GLatLng(66.187624148352413,27.594566345214844);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1451102.html','Kt 81 Pernu'));
var point = new GLatLng(66.684998430577153,27.977800369262699);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450300.html','Kt 82 Joutsijärvi'));
var point = new GLatLng(66.720845318035401,26.954612731933594);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453400.html','Kt 82 Kemijärvi, Hyypiö'));
var point = new GLatLng(69.307859447028790,26.670427322387695);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452200.html','Kt 92 Utsjoki, Kaamasmukka'));
var point = new GLatLng(65.465425706366787,27.652845382690437);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1254201.html','St 862 Pudasjärvi, Iso-Syöte'));
var point = new GLatLng(65.981431582084937,28.176670074462887);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452501.html','St 863 Livojärvi'));
var point = new GLatLng(65.835402910987256,25.321426391601562);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453001.html','St 924 Alaniemi'));
var point = new GLatLng(66.534049425537646,24.619674682617188);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453702.html','St 932 Ylitornio, Meltosjärvi'));
var point = new GLatLng(66.843874885746956,24.869098663330078);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453800.html','St 935 Pello, Rattosjärvi'));
var point = new GLatLng(67.617981175023914,24.151382446289062);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450102.html','St 940 Äkäslompolo'));
var point = new GLatLng(66.755352983428693,28.769073486328129);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1454300.html','St 950 Sallatunturi'));
var point = new GLatLng(68.660178384246876,26.311054229736328);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1450801.html','St 955 Inari, Hirvaspää'));
var point = new GLatLng(68.386537511764601,24.203567504882812);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1452401.html','St 956 Enontekiö, Peltovuoma'));
var point = new GLatLng(67.157430086772621,26.917190551757812);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453602.html','St 962 Sodankylä, Luosto'));
var point = new GLatLng(70.081263963876324,27.873172760009769);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1453302.html','St 970 Utsjoki, Nuorgam'));
var point = new GLatLng(67.602419114816186,24.172668457031246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1454402.html','St 9401 Ylläs, Maisemantie'));
var point = new GLatLng(61.003078649851041,23.115234375000000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0250601.html','Vt 2 Leppijärvi'));
var point = new GLatLng(61.306847663123222,22.131958007812496);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0251902.html','Vt 2 Harjavalta'));
var point = new GLatLng(61.448245243059027,21.832752227783203);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252300.html','Vt 2 Honkaluoto'));
var point = new GLatLng(63.056048292671683,21.712074279785153);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1050802.html','Vt 3 Vaasa'));
var point = new GLatLng(62.617194152847169,22.423095703125000);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051401.html','Vt 3 Kurikka, Tuiskula'));
var point = new GLatLng(61.010400727270770,24.423980712890625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450209.html','Vt 3 Hämeenlinna'));
var point = new GLatLng(61.600028619887610,23.382339477539062);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450601.html','Vt 3 Sasi'));
var point = new GLatLng(62.012023792252783,23.017387390136722);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451602.html','Vt 3 Parkano'));
var point = new GLatLng(61.001872009143703,25.794868469238281);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453602.html','Vt 4 Ahtiala'));
var point = new GLatLng(61.186948433435894,25.998802185058594);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0452602.html','Vt 4 Heinola'));
var point = new GLatLng(62.668429705128887,25.746116638183597);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950101.html','Vt 4 Petomäki'));
var point = new GLatLng(61.753712410533602,26.107635498046875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950901.html','Vt 4 Joutsa'));
var point = new GLatLng(62.513823302022892,25.687923431396484);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950601.html','Vt 4 Hirvaskangas'));
var point = new GLatLng(62.246347170476106,25.872287750244144);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951002.html','Vt 4 Vaajakoski'));
var point = new GLatLng(62.300735629677050,25.714616775512695);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951501.html','Vt 4 Puuppola'));
var point = new GLatLng(62.290201046864837,25.720453262329105);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0952009.html','Vt 4 Palokka'));
var point = new GLatLng(63.138497961584378,25.767316818237305);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951301.html','Vt 4 Taimoniemi'));
var point = new GLatLng(62.072503220060625,26.040129661560059);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950702.html','Vt 4 Vesto'));
var point = new GLatLng(63.490839498327027,25.667495727539062);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250501.html','Vt 4 Elämäjärvi'));
var point = new GLatLng(61.435402404959312,26.664333343505859);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352301.html','Vt 5 Mäntyharju, Vihantasalmi'));
var point = new GLatLng(61.407893562789567,26.405639648437504);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353201.html','Vt 5 Pertunmaa, Kuortti'));
var point = new GLatLng(63.735732007847844,23.017730712890625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1050201.html','Vt 8 Kruunupyy'));
var point = new GLatLng(62.261211919649725,21.487197875976559);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1050301.html','Vt 8 Lapväärtti'));
var point = new GLatLng(63.160129883892346,21.842193603515625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1050501.html','Vt 8 Koivulahti'));
var point = new GLatLng(64.011637979050832,23.552284240722656);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051200.html','Vt 8 Lohtaja'));
var point = new GLatLng(63.296102204365027,22.371940612792969);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051301.html','Vt 8 Oravainen'));
var point = new GLatLng(64.195320151455292,23.749694824218754);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250201.html','Vt 8 Rahja'));
var point = new GLatLng(61.528587584977615,21.803569793701175);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252402.html','Vt 8 Hyvelä'));
var point = new GLatLng(61.741686407644835,24.801464080810547);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453501.html','Vt 9 Längelmäki'));
var point = new GLatLng(61.544786581617352,24.051475524902344);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450402.html','Vt 9 Suinula'));
var point = new GLatLng(61.684824408011558,24.357719421386719);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451301.html','Vt 9 Orivesi'));
var point = new GLatLng(62.124677026837496,25.659599304199219);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950301.html','Vt 9 Muurame'));
var point = new GLatLng(62.252981270805350,26.101627349853516);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950402.html','Vt 9 Metsolahti'));
var point = new GLatLng(62.357295847880309,26.569147109985348);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950501.html','Vt 9 Nälkämäki'));
var point = new GLatLng(61.887427889295459,25.283575057983398);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951201.html','Vt 9 Himos'));
var point = new GLatLng(62.223836304698565,25.726203918457031);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951102.html','Vt 9 Pumperi'));
var point = new GLatLng(61.827633953199282,25.077667236328125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951809.html','Vt 9 Partalanmäki'));
var point = new GLatLng(61.476661211108755,22.574501037597656);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0250402.html','Vt 11 Tervahauta'));
var point = new GLatLng(61.498785564099485,23.477096557617188);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450802.html','Vt 11 Nokia, Murhasaari'));
var point = new GLatLng(61.097802171971701,21.849060058593750);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0251709.html','Vt 12 Lapinmäki'));
var point = new GLatLng(61.330410305488115,24.287338256835938);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453102.html','Vt 12 Pälkäne'));
var point = new GLatLng(61.108088367921717,24.849700927734375);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450501.html','Vt 12 Tuulos'));
var point = new GLatLng(60.987055717805326,25.540981292724609);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451200.html','Vt 12 Lahti, Kärpäsenmäki'));
var point = new GLatLng(61.398773343909220,23.255310058593750);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451902.html','Vt 12 Sarkola'));
var point = new GLatLng(63.254647626310735,24.294891357421875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051701.html','Vt 13 Perho, Oksakoski'));
var point = new GLatLng(62.010895954803750,26.633605957031243);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352602.html','Vt 13 Kangasniemi'));
var point = new GLatLng(62.906321577451038,24.895706176757812);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951402.html','Vt 13 Humppi'));
var point = new GLatLng(63.021959416141357,23.803253173828125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1052201.html','Vt 16 Alajärvi'));
var point = new GLatLng(63.006536286305355,22.152900695800778);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051601.html','Vt 16 Vähäkyrö, Tervajoki'));
var point = new GLatLng(62.551274438500052,24.148979187011719);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051502.html','Vt 18 Ähtäri, Inha'));
var point = new GLatLng(62.270558570721136,25.340137481689453);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951601.html','Vt 18 Kintaus'));
var point = new GLatLng(62.589073646661348,24.593925476074219);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951902.html','Vt 18 Väätäiskylä'));
var point = new GLatLng(63.084347536451773,22.995414733886719);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1050702.html','Vt 19 Kauhava'));
var point = new GLatLng(62.825369210033919,22.922115325927734);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1050101.html','Vt 19 Nurmo'));
var point = new GLatLng(62.250503645110221,23.780593872070312);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450109.html','Vt 23 Virrat'));
var point = new GLatLng(61.695570328899549,22.004585266113278);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0250509.html','Vt 23 Pomarkku'));
var point = new GLatLng(61.172549644526939,25.536003112792969);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0452201.html','Vt 24 Asikkala'));
var point = new GLatLng(61.605580066142480,25.248126983642575);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0950201.html','Vt 24 Patavesi'));
var point = new GLatLng(64.072499804707903,24.511184692382809);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1251802.html','Vt 27 Ylivieska'));
var point = new GLatLng(63.909302181074715,24.127349853515625);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1051901.html','Vt 28 Eskola'));
var point = new GLatLng(63.956070385636984,25.297393798828125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1253002.html','Vt 28 Karsikas'));
var point = new GLatLng(60.933101061395185,22.682647705078125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0251802.html','Kt 41 Virttaa'));
var point = new GLatLng(61.159800401929118,26.305389404296875);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353301.html','Kt 46 Uimila'));
var point = new GLatLng(61.057620800910456,26.484260559082028);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352801.html','Kt 46 Jaala'));
var point = new GLatLng(61.877841187294145,23.725662231445312);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451002.html','Kt 65 Kuru'));
var point = new GLatLng(62.803723277703767,23.517608642578125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1052002.html','Kt 66 Kuortane'));
var point = new GLatLng(62.486001417196405,21.733016967773438);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1052102.html','Kt 67 Teuva'));
var point = new GLatLng(62.702813107972602,26.468124389648441);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0952102.html','Kt 69 Konnevesi, Istunmäki'));
var point = new GLatLng(63.182868638826214,26.323928833007812);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0852601.html','Kt 77 Keitele'));
var point = new GLatLng(64.095607494280756,26.342124938964844);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1250801.html','Kt 88 Pyhäntä'));
var point = new GLatLng(61.507139560832286,25.695304870605472);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0452001.html','St 413 Sysmä'));
var point = new GLatLng(60.988679187913242,25.733842849731445);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451100.html','Lahti, Upon silta'));
var point = new GLatLng(61.777425616214757,23.282775878906246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453702.html','Tie 3 Luhalahti'));
var point = new GLatLng(61.505010323746248,25.985755920410156);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453801.html','Tie 4 Pohjola'));
var point = new GLatLng(61.799417071649330,24.438400268554691);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0454201.html','Tie 58 Juupajoki'));
var point = new GLatLng(61.944763987587599,24.117050170898441);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0454302.html','Tie 66 Ruhala'));
var point = new GLatLng(62.708638178532631,21.607017517089844);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C1052601.html','Tie 8 Pörtom/Pirttikylä'));
var point = new GLatLng(61.451896074759887,23.639144897460941);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0452800.html','Vt 3 Pirkkala'));
var point = new GLatLng(61.463871082132179,23.724632263183594);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453000.html','Vt 3 Pirkkahalli, Tampere'));
var point = new GLatLng(61.466823116524381,23.601379394531246);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453300.html','Vt 3 Pirkkala, Rajaniemi'));
var point = new GLatLng(61.463215036501630,23.768920898437500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450700.html','Vt 3 Lakalaiva'));
var point = new GLatLng(61.503536151138739,23.563270568847656);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450900.html','Vt 3 Nokia, Pitkäniemi'));
var point = new GLatLng(61.498785564099485,23.883934020996097);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453400.html','Vt 12 Tampere, Alasjärvi'));
var point = new GLatLng(61.503536151138739,23.746261596679688);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0452100.html','Vt 12 Onkiniemi'));
var point = new GLatLng(61.509432422368775,23.691329956054688);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0452400.html','Vt 12 Paasikiventie'));
var point = new GLatLng(60.252163958370467,24.530239105224609);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0251202.html','Vt 1 Kolmperä'));
var point = new GLatLng(60.371617143347279,23.323116302490231);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0251309.html','Vt 1 Muurla'));
var point = new GLatLng(60.315473295055526,24.231376647949219);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150601.html','Vt 1 Myllylampi'));
var point = new GLatLng(60.423512946032616,22.689857482910156);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252709.html','Vt 1 Kurjenmäki'));
var point = new GLatLng(60.537696723256069,24.234466552734375);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150401.html','Vt 2 Karkkila'));
var point = new GLatLng(60.816966220306966,23.594856262207035);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450301.html','Vt 2 Forssa'));
var point = new GLatLng(60.567065651980705,24.818801879882809);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150902.html','Vt 3 - Vt 25 Hyvinkää'));
var point = new GLatLng(60.732315172018772,24.726448059082031);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451801.html','Vt 3 Riihimäki'));
var point = new GLatLng(60.640876366391069,25.300140380859375);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150802.html','Vt 4 Mäntsälä'));
var point = new GLatLng(60.891124063492235,26.904830932617188);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350402.html','Vt 6 Utti'));
var point = new GLatLng(60.872914073084800,26.603565216064453);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350601.html','Vt 6 Keltti'));
var point = new GLatLng(61.608926780918885,29.500694274902344);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352202.html','Vt 6 Särkisalmi'));
var point = new GLatLng(61.028719321546234,28.065218925476071);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352104.html','Vt 6 Selkäharju'));
var point = new GLatLng(60.928221885207719,27.581262588500980);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0351101.html','Vt 6 Taavetti'));
var point = new GLatLng(61.090998172228865,28.362922668457035);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352901.html','Vt 6 Lappeenranta, Muukko'));
var point = new GLatLng(60.552637700142839,26.998214721679688);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350100.html','Vt 7 Rantahaka'));
var point = new GLatLng(60.415293147646231,25.653762817382812);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150202.html','Vt 7 Porvoo'));
var point = new GLatLng(60.310797363874883,25.387344360351562);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0151402.html','Vt 7 Sipoo'));
var point = new GLatLng(60.494354225424544,26.446237564086914);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350202.html','Vt 7 Ahvenkoski'));
var point = new GLatLng(60.559979041457176,27.269182205200195);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353001.html','Vt 7 Lelu'));
var point = new GLatLng(60.568457482253642,27.465047836303711);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353702.html','Vt 7 Uski'));
var point = new GLatLng(60.605003196094941,27.873001098632809);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0351202.html','Vt 7 Vaalimaa'));
var point = new GLatLng(60.606688275200234,27.869310379028320);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0351402.html','Vt 7 Vaalimaa, rekkaparkki'));
var point = new GLatLng(60.796033806001482,21.860561370849609);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0250701.html','Vt 8 Nästi'));
var point = new GLatLng(61.528587584977615,21.803054809570312);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252402.html','Vt 8 Hyvelä'));
var point = new GLatLng(60.650806011124736,22.569007873535156);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0250901.html','Vt 9 Aura'));
var point = new GLatLng(61.740304741667551,24.798545837402344);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0453501.html','Vt 9 Längelmäki'));
var point = new GLatLng(61.545195537836165,24.053878784179688);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0450402.html','Vt 9 Suinula'));
var point = new GLatLng(61.684987252911036,24.353256225585938);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451301.html','Vt 9 Orivesi'));
var point = new GLatLng(61.833833325990611,25.098180770874023);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0951809.html','Vt 9 Partalanmäki'));
var point = new GLatLng(60.596407924145161,22.862892150878903);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0251501.html','Vt 10 Marttila'));
var point = new GLatLng(60.510836276082294,26.920452117919915);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352401.html','Vt 15 Kotka, Kotkansaari'));
var point = new GLatLng(60.748508346027563,26.842861175537106);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0351901.html','Vt 15 Anjalankoski,Keltakangas'));
var point = new GLatLng(60.889954926764112,26.760635375976559);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0353101.html','Vt 15 Kouvola, Käyrälampi'));
var point = new GLatLng(59.865504353036449,23.065795898437500);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150702.html','Vt 25 Hanko'));
var point = new GLatLng(60.574741060738909,27.134857177734379);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0352002.html','Vt 26 Ruissalo'));
var point = new GLatLng(60.493931498528539,22.307910919189450);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252004.html','Kt 40 Kärsämäki'));
var point = new GLatLng(60.490464930090809,22.182769775390621);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252103.html','Kt 40 Raisio'));
var point = new GLatLng(60.469700040372267,22.367649078369141);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252203.html','Kt 40 Ravattula'));
var point = new GLatLng(60.051645813771763,23.930282592773441);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150301.html','Kt 51 Inkoo'));
var point = new GLatLng(60.631112038010244,23.519668579101562);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0250809.html','Kt 52 Somero'));
var point = new GLatLng(59.999071953812241,23.405170440673828);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0150501.html','Kt 52 Tenhola'));
var point = new GLatLng(60.722158808174690,24.439601898193359);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0451702.html','Kt 54 Loppi'));
var point = new GLatLng(60.193425373151165,22.039604187011719);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0252602.html','St 180 Prostvik'));
var point = new GLatLng(60.461195711302551,22.158908843994141);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0250302.html','St 185 Nesteentie'));
var point = new GLatLng(60.681669337304768,21.465396881103516);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0251601.html','St 196 Lokalahti'));
var point = new GLatLng(60.942607052297689,26.797800064086914);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0350300.html','Kouvola'));
var point = new GLatLng(60.827510970367165,24.018688201904300);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0454002.html','Tie 54 Perähuhta'));
var point = new GLatLng(60.881352103588306,25.265808105468757);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0454109.html','Tie 54 Kärkölä'));
var point = new GLatLng(61.794630603839792,24.432048797607425);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0454201.html','Tie 58 Juupajoki'));
var point = new GLatLng(60.347676517105505,25.109424591064453);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0153202.html','Tie 4 Korso'));
var point = new GLatLng(60.374332699612737,24.811935424804688);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0153301.html','Tie 3 Klaukkala'));
var point = new GLatLng(60.255315303152855,25.068397521972660);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0152301.html','Vt 4 Tattarinsuo'));
var point = new GLatLng(60.169695524940053,24.802579879760746);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0151700.html','Kt 51 Hakalehto'));
var point = new GLatLng(60.164977388120967,24.912185668945309);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0152000.html','Kt 51 Ruoholahti'));
var point = new GLatLng(60.135778197242061,24.520282745361332);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0152402.html','Kt 51 Jorvas'));
var point = new GLatLng(60.200016324562220,24.808888435363770);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0152101.html','St 101 Turvesuontie'));
var point = new GLatLng(60.209143352502373,24.815969467163089);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0151201.html','St 101 - Vt 1 Leppävaara'));
var point = new GLatLng(60.244582454265462,24.947376251220707);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0151302.html','St 101 - Kt 45 Pakila'));
var point = new GLatLng(60.293192857898838,24.857940673828125);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0153401.html','Tie 50 (Kehä III), Vantaankoski'));
var point = new GLatLng(60.235316154962952,24.899525642395016);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0153501.html','Tie 101 (Kehä I), Pirkkola'));
var point = new GLatLng(60.288173411494874,24.980421066284180);
 (createMarker(point,'http://alk.tiehallinto.fi/alk/kelikamerat/kamera-C0151104.html','Tie 45 Veromies'));

// Zoom to Finland
map.setCenter( new GLatLng(63.87939,25.532227),5);

